import 'package:clean_android_design/src/utils/validation/validator.dart';
import 'package:flutter/material.dart';

class DateTimeValidation<T> implements IValidation {
  final String Function(T, DateTime dateTime) validateFunction;
  final FocusNode focusNode;

  DateTime Function() _getDateTime;
  T Function() _getItem;
  void Function(String errorMessage) _onValidate;
  Validator<T> _validator;

  DateTimeValidation({
    @required Validator<T> validator,
    @required this.validateFunction,
    this.focusNode,
  }) {
    _validator = validator;
    _validator.addValidation(this);
  }

  @override
  bool validate() {
    if (_getItem == null || _getDateTime == null || validateFunction == null)
      return true;
    var errorMessage = validateFunction(_getItem(), _getDateTime());
    _onValidate?.call(errorMessage);
    return errorMessage == null;
  }

  void initialize(
      {@required DateTime Function() getDateTimeFunction,
      @required T Function() getItemFunction,
      @required void Function(String errorMessage) onValidate}) {
    _getDateTime = getDateTimeFunction;
    _getItem = getItemFunction;
    _onValidate = onValidate;
  }
}
