import 'package:clean_android_design/src/utils/validation/validator.dart';
import 'package:flutter/material.dart';

class TextValidation<T> implements IValidation {
  final String Function(T, String string) validateFunction;
  final FocusNode focusNode;

  String Function() _getText;
  T Function() _getItem;
  void Function(String errorMessage) _onValidate;
  Validator<T> _validator;

  TextValidation({
    @required Validator<T> validator,
    @required this.validateFunction,
    this.focusNode,
  }) {
    _validator = validator;
    _validator.addValidation(this);
  }

  @override
  bool validate() {
    if (_getItem == null || _getText == null || validateFunction == null)
      return true;
    var errorMessage = validateFunction(_getItem(), _getText());
    _onValidate?.call(errorMessage);
    return errorMessage == null;
  }

  void initialize(
      {@required String Function() getTextFunction,
      @required T Function() getItemFunction,
      @required void Function(String errorMessage) onValidate}) {
    _getText = getTextFunction;
    _getItem = getItemFunction;
    _onValidate = onValidate;
  }
}
